@@ -337,7 +337,7 @@ def fis_bs_lollipop(df,valor1,valor2,figsize=(12,4),dpi=100,linewidth=5,size=10,
     plt.yticks([])                                    
     return f, ax
 
-def fis_bs_mekko(ynp_values,xnp_values,x_labels,figsize=(12,5),color1='light blue',color2='grey',xticks_size=14,legend1='val1',legend2='val2',title_size=20,legend_size=20,label_y="",label_x=""):
+def fis_bs_mekko(ynp_values,xnp_values,x_label,figsize=(12,5),color1='light blue',color2='grey',xticks_size=14,legend1='val1',legend2='val2',title_size=20,legend_size=20,label_y="",label_x=""):
     # calculate x coordinates based on the width of the previous bars
     # same as: [0, width[0], width[0] + width[1], width[0] + width[1] + width[2]]
     y = ynp_values
